+
drawEllipse
@@ -1316,7 +1316,7 @@
-
Draws an elipse.
+
Draws an ellipse.
diff --git a/docs/data.json b/docs/data.json
index 7f424e1..fb8d8b0 100644
--- a/docs/data.json
+++ b/docs/data.json
@@ -3811,9 +3811,9 @@
{
"file": "src/pixi/primitives/Graphics.js",
"line": 190,
- "description": "Draws an elipse.",
+ "description": "Draws an ellipse.",
"itemtype": "method",
- "name": "drawElipse",
+ "name": "drawEllipse",
"params": [
{
"name": "x",
@@ -6159,4 +6159,4 @@
"line": " src/pixi/Pixi.js:1"
}
]
-}
\ No newline at end of file
+}
diff --git a/docs/files/src_pixi_primitives_Graphics.js.html b/docs/files/src_pixi_primitives_Graphics.js.html
index 9041f75..778e5be 100644
--- a/docs/files/src_pixi_primitives_Graphics.js.html
+++ b/docs/files/src_pixi_primitives_Graphics.js.html
@@ -360,15 +360,15 @@
}
/**
- * Draws an elipse.
+ * Draws an ellipse.
*
- * @method drawElipse
+ * @method drawEllipse
* @param x {Number}
* @param y {Number}
* @param width {Number}
* @param height {Number}
*/
-PIXI.Graphics.prototype.drawElipse = function( x, y, width, height)
+PIXI.Graphics.prototype.drawEllipse = function( x, y, width, height)
{
if(this.currentPath.points.length == 0)this.graphicsData.pop();
diff --git a/docs/files/src_pixi_renderers_canvas_CanvasGraphics.js.html b/docs/files/src_pixi_renderers_canvas_CanvasGraphics.js.html
index a0ec34a..920213e 100644
--- a/docs/files/src_pixi_renderers_canvas_CanvasGraphics.js.html
+++ b/docs/files/src_pixi_renderers_canvas_CanvasGraphics.js.html
@@ -276,15 +276,15 @@
else if(data.type == PIXI.Graphics.ELIP)
{
- // elipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
+ // ellipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
- var elipseData = data.points;
+ var ellipseData = data.points;
- var w = elipseData[2] * 2;
- var h = elipseData[3] * 2;
+ var w = ellipseData[2] * 2;
+ var h = ellipseData[3] * 2;
- var x = elipseData[0] - w/2;
- var y = elipseData[1] - h/2;
+ var x = ellipseData[0] - w/2;
+ var y = ellipseData[1] - h/2;
context.beginPath();
@@ -378,14 +378,14 @@
else if(data.type == PIXI.Graphics.ELIP)
{
- // elipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
- var elipseData = data.points;
+ // ellipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
+ var ellipseData = data.points;
- var w = elipseData[2] * 2;
- var h = elipseData[3] * 2;
+ var w = ellipseData[2] * 2;
+ var h = ellipseData[3] * 2;
- var x = elipseData[0] - w/2;
- var y = elipseData[1] - h/2;
+ var x = ellipseData[0] - w/2;
+ var y = ellipseData[1] - h/2;
context.beginPath();
diff --git a/src/pixi/renderers/canvas/CanvasGraphics.js b/src/pixi/renderers/canvas/CanvasGraphics.js
index f5352b9..6235353 100644
--- a/src/pixi/renderers/canvas/CanvasGraphics.js
+++ b/src/pixi/renderers/canvas/CanvasGraphics.js
@@ -104,15 +104,15 @@
else if(data.type == PIXI.Graphics.ELIP)
{
- // elipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
+ // ellipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
- var elipseData = data.points;
+ var ellipseData = data.points;
- var w = elipseData[2] * 2;
- var h = elipseData[3] * 2;
+ var w = ellipseData[2] * 2;
+ var h = ellipseData[3] * 2;
- var x = elipseData[0] - w/2;
- var y = elipseData[1] - h/2;
+ var x = ellipseData[0] - w/2;
+ var y = ellipseData[1] - h/2;
context.beginPath();
@@ -208,14 +208,14 @@
else if(data.type == PIXI.Graphics.ELIP)
{
- // elipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
- var elipseData = data.points;
+ // ellipse code taken from: http://stackoverflow.com/questions/2172798/how-to-draw-an-oval-in-html5-canvas
+ var ellipseData = data.points;
- var w = elipseData[2] * 2;
- var h = elipseData[3] * 2;
+ var w = ellipseData[2] * 2;
+ var h = ellipseData[3] * 2;
- var x = elipseData[0] - w/2;
- var y = elipseData[1] - h/2;
+ var x = ellipseData[0] - w/2;
+ var y = ellipseData[1] - h/2;
context.beginPath();
diff --git a/src/pixi/primitives/Graphics.js b/src/pixi/primitives/Graphics.js
index 8e8c3dd..7184b3b 100644
--- a/src/pixi/primitives/Graphics.js
+++ b/src/pixi/primitives/Graphics.js
@@ -188,15 +188,15 @@
}
/**
* Draws an elipse.
*
- * @method drawElipse
+ * @method drawEllipse
* @param x {Number}
* @param y {Number}
* @param width {Number}
* @param height {Number}
*/
-PIXI.Graphics.prototype.drawElipse = function( x, y, width, height)
+PIXI.Graphics.prototype.drawEllipse = function( x, y, width, height)
{
if(this.currentPath.points.length == 0)this.graphicsData.pop();
@@ -188,15 +188,15 @@
}
/**
- * Draws an elipse.
+ * Draws an ellipse.
*